--[[
Environment Inspector v1.1 – credit @Jieshuolibrary
Fixed: os.getenv(nil) crash on some Android builds.
]]

-- Color helpers (ignored on Windows / some Android consoles)
local RESET  = "\27[0m"
local GREEN  = "\27[32m"
local YELLOW = "\27[33m"

local function safeString(v, limit)
  limit = limit or 80
  local t = type(v)
  if t == "string" then
    return '"' .. v:gsub("\n","\\n") .. '"'
  elseif t == "table" then
    local s, n = "{ ", 0
    for k,_ in pairs(v) do
      n = n + 1
      if n > 5 then s = s .. "... }"; break end
      s = s .. tostring(k) .. " "
    end
    if n <= 5 then s = s .. "}" end
    return s
  else
    return tostring(v)
  end
end

print(GREEN .. "==== Environment Inspector ====" .. RESET)
print("Lua version : " .. (_G["_VERSION"] or "unknown"))
print("OS          : " .. (os.getenv("OS") or os.getenv("OSTYPE") or "Android"))
print("Path sep    : " .. (package.config:sub(1,1) or "/"))
print("")

print(YELLOW .. "1) Global variables (_G):" .. RESET)
local gKeys = {}
for k in pairs(_G) do gKeys[#gKeys+1] = k end
table.sort(gKeys)
for _,k in ipairs(gKeys) do
  io.write(string.format("  %-20s = %s\n", k, safeString(_G[k])))
end

print("")
print(YELLOW .. "2) package.loaded modules:" .. RESET)
local loaded = {}
for k in pairs(package.loaded) do loaded[#loaded+1] = k end
table.sort(loaded)
for _,k in ipairs(loaded) do
  io.write("  " .. k .. "\n")
end

print("")
print(YELLOW .. "3) package.path:" .. RESET)
print("  " .. package.path:gsub(";","\n  "))
print(YELLOW .. "4) package.cpath:" .. RESET)
print("  " .. package.cpath:gsub(";","\n  "))

print(YELLOW .. "5) Environment variables:" .. RESET)
local envTable = {}
local ok, envPairs = pcall(function()
  -- os.execute("env") alternative for Android
  local handle = io.popen("env 2>/dev/null")
  if handle then
    for line in handle:lines() do
      local k, v = line:match("^([^=]+)=(.*)$")
      if k then envTable[k] = v end
    end
    handle:close()
  end
  return envTable
end)
if ok and next(envPairs) then
  local envKeys = {}
  for k in pairs(envPairs) do envKeys[#envKeys+1] = k end
  table.sort(envKeys)
  for _,k in ipairs(envKeys) do
    io.write(string.format("  %-25s = %s\n", k, envPairs[k]))
  end
else
  print("  (none accessible)")
end

if activity or service then
  print("")
  print(YELLOW .. "6) Androlua / Android objects:" .. RESET)
  if activity then print("  activity = " .. tostring(activity)) end
  if service  then print("  service  = " .. tostring(service)) end
end

print(GREEN .. "==== End of report ====" .. RESET)
print("💬 Join our Telegram channel: https://t.me/Jieshuolibrary")
